import BookTrackerPlugin from "@src/main";
import { App } from "obsidian";

export class Storage {
	public constructor(
		private readonly app: App,
		private readonly plugin: BookTrackerPlugin
	) {}

	private getFilePath(filename: string): string {
		return `${this.plugin.manifest.dir!!}/${filename}`;
	}

	public async readJSON<T>(filename: string): Promise<T | null> {
		const filePath = this.getFilePath(filename);
		const content = await this.app.vault.adapter.read(filePath);
		if (!content) {
			return null;
		}

		try {
			return JSON.parse(content) as T;
		} catch (error) {
			console.error(`Error parsing JSON from ${filePath}:`, error);
			return null;
		}
	}

	public async writeJSON<T>(filename: string, data: T): Promise<void> {
		const filePath = this.getFilePath(filename);
		const content = JSON.stringify(data, null, 2);
		await this.app.vault.adapter.write(filePath, content);
	}
}
